package main

import (
	"context"
	"fmt"
	"testing"

	"github.com/jackc/pgx/v5/pgxpool"
	"github.com/spf13/viper"
)

func TestDB(t *testing.T) {
	cfg := DefaultConfig()
	cfg.DB.Password = viper.GetString(ViperDBPassword)

	ctx := context.Background()

	//prep
	pool, err := pgxpool.New(
		ctx,
		fmt.Sprintf(
			"user=%s password=%s database=%s host=%s port=%d sslmode=%s ",
			cfg.DB.User,
			cfg.DB.Password,
			cfg.DB.Database,
			cfg.DB.Host,
			cfg.DB.Port,
			cfg.DB.SSLMode,
		))
	if err != nil {
		t.Error(err)
		return
	}
	defer pool.Close()

	db := &PostgresClient{
		Ctx:  ctx,
		Pool: pool,
	}

	//exec

	t.Run("create or replace schema",
		func(t *testing.T) {
			if err := db.CreateOrReplaceSchema(); err != nil {
				t.Error(err)
			}
		})
}
